==> scoutbook_parser-0.12.2.tar.gz: scoutbook_parser-0.12.2/scoutbook_parser/parser.py <==
from .utils import DateTimeEncoder
from .advancement import record_advancement
from .personal_data import read_personal


class Parser:
    def __init__(
        self,
        input_personal=None,
        input_advancement=None,
        outfile="output",
        file_format="yaml",
        cub_scouts=False,
    ):
        if input_personal:
            scouts = read_personal(file=input_personal)
            self.scouts = record_advancement(
                file=input_advancement, scouts=scouts)
            )
        else:
            self.scouts = record_advancement(file=input_advancement, scouts=None)
        self.outfile = outfile
        self.file_format = file_format

    def dump(self):
        match self.file_format:
            case "yaml":
                import yaml

                with open(self.outfile, "w") as f:
                    yaml.safe_dump(self.scouts, f)
            case "toml":
                import toml

                with open(self.outfile, "w") as f:
                    toml.dump(self.scouts, f)
            case "json":
                import json

                with open(self.outfile, "w") as f:
                    json.dump(self.scouts, f, cls=DateTimeEncoder)

    def dumps(self):
        match self.file_format:
            case "yaml":
                import yaml

                output_func = yaml.safe_dump
            case "toml":
                import toml

                output_func = toml.dumps
            case "json":
                import json

                return json.dumps(self.scouts, cls=DateTimeEncoder)

        return output_func(self.scouts)


if __name__ == "__main__":
    parser = Parser(
        input_personal="Output_personal_data.csv",
        input_advancement="Output_advancement_data.csv",
        outfile="Output_scouts.yaml",
        file_format="yaml",
    )

    print(parser.dumps())

==> scoutbook_parser-0.13.2.tar.gz: scoutbook_parser-0.13.2/scoutbook_parser/parser.py <==
from .utils import DateTimeEncoder
from .advancement import record_advancement
from .personal_data import read_personal


class Parser:
    def __init__(
        self,
        input_personal=None,
        input_advancement=None,
        outfile="output",
        file_format="yaml",
        cub_scouts=False,
    ):
        if input_personal:
            scouts = read_personal(file=input_personal)
            self.scouts = record_advancement(file=input_advancement, scouts=scouts)
        else:
            self.scouts = record_advancement(file=input_advancement, scouts=None)
        self.outfile = outfile
        self.file_format = file_format

    def dump(self):
        match self.file_format:
            case "yaml":
                import yaml

                with open(self.outfile, "w") as f:
                    yaml.safe_dump(self.scouts, f)
            case "toml":
                import toml

                with open(self.outfile, "w") as f:
                    toml.dump(self.scouts, f)
            case "json":
                import json

                with open(self.outfile, "w") as f:
                    json.dump(self.scouts, f, cls=DateTimeEncoder)

    def dumps(self):
        match self.file_format:
            case "yaml":
                import yaml

                output_func = yaml.safe_dump
            case "toml":
                import toml

                output_func = toml.dumps
            case "json":
                import json

                return json.dumps(self.scouts, cls=DateTimeEncoder)

        return output_func(self.scouts)


if __name__ == "__main__":
    parser = Parser(
        input_personal="Output_personal_data.csv",
        input_advancement="Output_advancement_data.csv",
        outfile="Output_scouts.yaml",
        file_format="yaml",
    )

    print(parser.dumps())
